#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# MOD Duo hardware tests
# Copyright (C) 2016-2020 Filipe Coelho <falktx@falktx.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# For a full copy of the GNU General Public License see the LICENSE file.

# ------------------------------------------------------------------------------------------------------------
# Imports

# usual stuff
import os

# local
from config import MOD_IP, MOD_HOST_IP, devInfo, testStream
from test_abstract import ExtendedTestCase

# ------------------------------------------------------------------------------------------------------------

class TestNetworkRegisterHost(ExtendedTestCase):
    def test_register(self):
        if testStream.from_pc:
            return

        try:
            self.assertCommand("ifconfig usb1 %s" % MOD_HOST_IP)
        except AssertionError as e:
            testStream.print("Failed to register network device (USB Loopback not connected?)")
            raise e

    def test_usb_stick(self):
        if not testStream.from_pc:
            return

        try:
            self.assertTrue(os.path.exists("/dev/sda"))
        except AssertionError as e:
            testStream.print("Failed to recognize USB stick for testing via MOD-Factory-Deploy GUI")
            raise e

class TestNetworkPing(ExtendedTestCase):
    def test_localhost(self):
        try:
            self.assertCommand("ping -c 1 localhost")
        except AssertionError as e:
            testStream.print("Software network loopback ping failed (localhost)")
            raise e

    def test_modduo(self):
        try:
            self.assertCommand("ping -c 1 mod%s" % devInfo.platform)
        except AssertionError as e:
            testStream.print("Software network loopback ping failed (custom name)")
            raise e

    def test_127_0_0_1(self):
        try:
            self.assertCommand("ping -c 1 127.0.0.1")
        except AssertionError as e:
            testStream.print("Software network loopback ping failed (127.0.0.1)")
            raise e

    def test_mod_ip(self):
        try:
            self.assertCommand("ping -c 1 %s" % MOD_IP)
        except AssertionError as e:
            testStream.print("Network ping failed (USB Gadget not connected?)")
            raise e

    def test_mod_host_ip(self):
        if testStream.from_pc:
            return
        try:
            self.assertCommand("ping -c 1 %s" % MOD_HOST_IP)
        except AssertionError as e:
            testStream.print("Network ping failed (USB Loopback not connected?)")
            raise e

# ------------------------------------------------------------------------------------------------------------

tests = [
    TestNetworkRegisterHost,
    TestNetworkPing
]

# ------------------------------------------------------------------------------------------------------------
